@@ -16,8 +16,7 @@ API_URL_SCAFFOLD = "https://api.openuv.io/api/v1"
 
 DEFAULT_PROTECTION_HIGH = 3.5
 DEFAULT_PROTECTION_LOW = 3.5
-DEFAULT_REQUEST_RETRIES = 3
-DEFAULT_REQUEST_RETRY_INTERVAL = 3
+DEFAULT_REQUEST_RETRIES = 4
 DEFAULT_TIMEOUT = 30
 
 
@@ -33,7 +32,7 @@ class Client:
         altitude: float = 0.0,
         session: Optional[ClientSession] = None,
         request_retries: int = DEFAULT_REQUEST_RETRIES,
-        request_retry_interval: int = DEFAULT_REQUEST_RETRY_INTERVAL,
+        logger: Optional[logging.Logger] = None,
     ) -> None:
         """Initialize."""
         self._api_key = api_key
@@ -42,13 +41,16 @@ class Client:
         self.latitude = str(latitude)
         self.longitude = str(longitude)
 
+        if logger:
+            self._logger = logger
+        else:
+            self._logger = _LOGGER
+
         # Implement a version of the request coroutine, but with backoff/retry logic:
         self.async_request = backoff.on_exception(
-            backoff.constant,
+            backoff.expo,
             (asyncio.TimeoutError, ClientError),
-            giveup=self._is_unauthorized_exception,
-            interval=request_retry_interval,
-            logger=_LOGGER,
+            logger=self._logger,
             max_tries=request_retries,
             on_giveup=self._handle_on_giveup,
         )(self._async_request)
@@ -83,6 +85,8 @@ class Client:
         if not use_running_session:
             await session.close()
 
+        self._logger.debug("Received data for %s: %s", endpoint, data)
+
         return cast(Dict[str, Any], data)
 
     def _handle_on_giveup(self, _: Dict[str, Any]) -> None:
